==> SPOT_1.0.2662.tar.gz: SPOT/R/spotFuncStartSphere.R <==
###################################################################################################
#' Sphere function call interface for SPOT, deprecated
#'
#' SPOT uses this function for some demos to call the \code{\link{spotSphereFunction}} function 
#' 
#' @param spotConfig Contains the list of spot configurations, results of the algorithm can be passed to this list instead of the .res file.
#'		  spotConfig defaults to "NA", and will only be passed to the Algorithm if spotConfig$spot.fileMode=FALSE. See also: \code{\link{spotGetOptions}}
#'			Items used are: \cr \cr
#'			alg.currentDesign: data frame holding the design points that will be evaluated \cr
#'			io.apdFileName: name of the apd file \cr
#'			io.desFileName: name of the des file \cr
#'			io.resFileName: name of the res file, for logging results (if spotConfig$spot.fileMode==TRUE)\cr
#'			spot.fileMode: boolean, if selected with true the results will also be written to the res file, otherwise it will only be saved in the spotConfig returned by this function\cr
#' @return this function returns the \code{spotConfig} list with the results in spotConfig$alg.currentResult
#' @seealso  \code{\link{SPOT}} \code{\link{spot}} \code{\link{demo}} \code{\link{optim}}
#' \code{\link{spotSphereFunction}}
#' @keywords internal
###################################################################################################
spotFuncStartSphere <- function(spotConfig){
	pdFile=spotConfig$io.apdFileName;
	resFileName=spotConfig$io.resFileName;	
	desFileName=spotConfig$io.desFileName;	
	if(is.null(spotConfig$spot.noise)){spotConfig$spot.noise=10.0}
	if(is.null(spotConfig$spot.noise.type)){spotConfig$spot.noise.type="weighted"}
	if(is.null(spotConfig$spot.noise.minimum.at.value)){spotConfig$spot.noise.minimum.at.value=0.0}
	## spot.noise.type in {"weighted", "constant"}
	## weighted: y = y + y * noiseValue / 100
	## constant: y = y + noiseValue
		
	if (spotConfig$spot.fileMode){ ##Check if spotConfig was passed to the algorithm, if yes the spot.fileMode is chosen with False wich means results have to be passed to spotConfig and not to res file.
		spotWriteLines(spotConfig$io.verbosity,1,paste("Loading design file data from::",  desFileName), con=stderr());
		## read doe/dace etc settings:
		des <- read.table(desFileName, sep=" ", header = TRUE);	
	}else{
		des <- spotConfig$alg.currentDesign; ##The if/else should not be necessary anymore, since des will always be written into the spotConfig
	}	
	#default Values that can be changed with apd file
	noise<-spotConfig$spot.noise;
	noise.type <- spotConfig$spot.noise.type;
	spot.noise.minimum.at.value <- spotConfig$spot.noise.minimum.at.value;
	f<-"Sphere"
	n<-3;
	## read problem design file
	if(file.exists(pdFile)){
		source(pdFile,local=TRUE)
	}
	## read doe/dace etc settings:
	##  VARX1 VARX2 VARX3 REPEATS SEED
	config<-nrow(des);	
	attach(des)	
	for (k in 1:config){
		for (i in 1:des$REPEATS[k]){
			##
			if (exists("VARX1")){
				x1 <- des$VARX1[k]
			} else {
        x1 <- NA;
			}
			if (exists("VARX2")){
				x2 <- des$VARX2[k]
			} else {
			  x2 <- NA;
			}
			if (exists("VARX3")){
				x3 <- des$VARX3[k]
			} else {
			  x3 <- NA;
			}
			conf <- k
			if (exists("CONFIG")){
				conf <- des$CONFIG[k]
			}
			if (exists("STEP")){
				step <- des$STEP[k]
			}
			seed <- des$SEED[k]+i-1			
			spotPrint(spotConfig$io.verbosity,1,c("Config:",k ," Repeat:",i))
      
      if (exists("VARX2")){
        if (exists("VARX3")){
          values <- c(x1,x2,x3);          
        } else {
          values <- c(x1,x2);
        }        
      } else{
        values <- c(x1);
      }
      
			y <- spotSphereFunction(values)
			## add noise
      y <- y + spotCalcNoise(y, noise=noise, noise.type=noise.type, spot.noise.minimum.at.value=spot.noise.minimum.at.value);
			
			spotPrint(spotConfig$io.verbosity,1,y)
			res <- NULL
			res <- list(Y=y,					
					VARX1=x1,
					VARX2=x2,
					VARX3=x3,
					Function=f,					
					DIM=n,
					STEP=step,
					SEED=seed,
					CONFIG=conf
			)
			res <-data.frame(res)			
			if (spotConfig$spot.fileMode){ ##Log the result in the .res file, only if user didnt set fileMode==FALSE
				colNames = TRUE
				if (file.exists(resFileName)){
					colNames = FALSE
				}				
				## quote = false is required for JAVA
				write.table(res
						, file = resFileName
						, row.names = FALSE
						, col.names = colNames
						, sep = " "              
						, append = !colNames
						, quote = FALSE
				);		
			}
			spotConfig$alg.currentResult=rbind(spotConfig$alg.currentResult,res);					
		}			
	}	
	detach(des)
	return(spotConfig)
}

==> SPOT_1.0.4184.tar.gz: SPOT/R/spotFuncStartSphere.R <==
###################################################################################################
#' Sphere function call interface for SPOT, deprecated
#'
#' SPOT uses this function for some demos to call the \code{\link{spotSphereFunction}} function 
#' 
#' @param spotConfig Contains the list of spot configurations, results of the algorithm can be passed to this list instead of the .res file.
#'		  spotConfig defaults to "NA", and will only be passed to the Algorithm if spotConfig$spot.fileMode=FALSE. See also: \code{\link{spotGetOptions}}
#'			Items used are: \cr \cr
#'			alg.currentDesign: data frame holding the design points that will be evaluated \cr
#'			io.apdFileName: name of the apd file \cr
#'			io.desFileName: name of the des file \cr
#'			io.resFileName: name of the res file, for logging results (if spotConfig$spot.fileMode==TRUE)\cr
#'			spot.fileMode: boolean, if selected with true the results will also be written to the res file, otherwise it will only be saved in the spotConfig returned by this function\cr
#' @return this function returns the \code{spotConfig} list with the results in spotConfig$alg.currentResult
#' @seealso  \code{\link{SPOT}} \code{\link{spot}} \code{\link{demo}} \code{\link{optim}}
#' \code{\link{spotSphereFunction}}
#' @keywords internal
###################################################################################################
spotFuncStartSphere <- function(spotConfig){
	pdFile=spotConfig$io.apdFileName
	resFileName=spotConfig$io.resFileName
	desFileName=spotConfig$io.desFileName
	if(is.null(spotConfig$spot.noise)){spotConfig$spot.noise=10.0}
	if(is.null(spotConfig$spot.noise.type)){spotConfig$spot.noise.type="weighted"}
	if(is.null(spotConfig$spot.noise.minimum.at.value)){spotConfig$spot.noise.minimum.at.value=0.0}
	## spot.noise.type in {"weighted", "constant"}
	## weighted: y = y + y * noiseValue / 100
	## constant: y = y + noiseValue
		
	if (spotConfig$spot.fileMode){ 
		spotWriteLines(spotConfig$io.verbosity,1,paste("Loading design file data from::",  desFileName), con=stderr())
		## read doe/dace etc settings:
		des <- read.table(desFileName, sep=" ", header = TRUE)
	}else{
		des <- spotConfig$alg.currentDesign 
	}	
	#default Values that can be changed with apd file
	noise<-spotConfig$spot.noise
	noise.type <- spotConfig$spot.noise.type
	spot.noise.minimum.at.value <- spotConfig$spot.noise.minimum.at.value
	f<-"Sphere"
	n<-3
	## read problem design file
	if(file.exists(pdFile)){
		source(pdFile,local=TRUE)
	}
	## read doe/dace etc settings:
	##  VARX1 VARX2 VARX3 REPEATS SEED
	config<-nrow(des)
	for (k in 1:config){
		for (i in 1:des$REPEATS[k]){
			##
			if (!is.null(des$VARX1)){
				x1 <- des$VARX1[k]
			} else {
				x1 <- NA;
			}
			if (!is.null(des$VARX2)){
				x2 <- des$VARX2[k]
			} else {
			  x2 <- NA;
			}
			if (!is.null(des$VARX3)){
				x3 <- des$VARX3[k]
			} else {
			  x3 <- NA;
			}
			conf <- k
			if (!is.null(des$CONFIG)){
				conf <- des$CONFIG[k]
			}
			if (!is.null(des$STEP)){
				step <- des$STEP[k]
			}
			seed <- des$SEED[k]+i-1			
			spotPrint(spotConfig$io.verbosity,1,c("Config:",k ," Repeat:",i))
      
      if (!is.null(des$VARX2)){ #TODO ???
        if (!is.null(des$VARX3)){
          values <- c(x1,x2,x3)       
        } else {
          values <- c(x1,x2)
        }        
      } else{
        values <- c(x1)
      }
      
			y <- spotSphereFunction(values)
			## add noise
      y <- y + spotCalcNoise(y, noise=noise, noise.type=noise.type, spot.noise.minimum.at.value=spot.noise.minimum.at.value)
			
			spotPrint(spotConfig$io.verbosity,1,y)
			res <- NULL
			res <- list(Y=y,					
					VARX1=x1,
					VARX2=x2,
					VARX3=x3,
					Function=f,					
					DIM=n,
					STEP=step,
					SEED=seed,
					CONFIG=conf)
			res <-data.frame(res)			
			if (spotConfig$spot.fileMode){ ##Log the result in the .res file, only if user didnt set fileMode==FALSE
				colNames = TRUE
				if (file.exists(resFileName)){
					colNames = FALSE
				}				
				## quote = false is required for JAVA
				write.table(res
						, file = resFileName
						, row.names = FALSE
						, col.names = colNames
						, sep = " "              
						, append = !colNames
						, quote = FALSE)	
			}
			spotConfig$alg.currentResult=rbind(spotConfig$alg.currentResult,res)					
		}			
	}	
	spotConfig
}
